==> cv-library-react-web-0.1.20.tgz: package/src/components/DataTableColumnHeader/DataTableColumnHeader.js <==
import React from 'react';
import * as PropTypes from 'prop-types';

import TextLabel from '../TextLabel/TextLabel';
import IconButton, { ICON_SIZE } from '../IconButton/IconButton';

/**
 * Data Table Column Header with sort and filter controls
 */
const DataTableColumnHeader = (props) => {
    console.log('DATA TABLE COLUMN HEADER PROPS: ', props); // eslint-disable-line

    const {
        column,
        displayName,
        enableSorting,
        filterableColumns,
        showFilters,
        onFilterToggle,
        onPinToggle,
        onSortChanged,
        sortDirection,
        sortDirections: SORT_DIRECTIONS,
    } = props;
    const {
        colDef,
        pinned,
    } = column;
    const {
        field,
    } = colDef;

    // Determine current sorting method
    const sortingAscending = sortDirection === SORT_DIRECTIONS.ASC;
    const sortingDescending = sortDirection === SORT_DIRECTIONS.DESC;
    const notSorting = !sortingAscending && !sortingDescending;

    // Determine next sorting method
    let nextSort = SORT_DIRECTIONS.ASC;
    if (sortDirection === SORT_DIRECTIONS.ASC) {
        nextSort = SORT_DIRECTIONS.DESC;
    }
    else if (sortDirection === SORT_DIRECTIONS.DESC) {
        nextSort = SORT_DIRECTIONS.NONE;
    }

    // Generate sort button props
    const sortProps = {
        contextStyles: {
            container: {},
            icon: {
                // Invert icon for sort descending as one was not in the core library
                transform: `scaleY(${sortingDescending ? -1 : 1})`,

                // Change opacity to denote cleared sort
                opacity: notSorting ? 0.25 : 1,
            },
        },
        iconName: 'sort',
        iconSize: ICON_SIZE.SMALL,
        onClick: () => {
            console.log('SORT EVENT: ', field); // eslint-disable-line
            if (onSortChanged) {
                onSortChanged(field, nextSort);
            }
        },
    };

    // Generate filter button props
    const filterProps = {
        iconName: 'filter_list',
        iconSize: ICON_SIZE.SMALL,
        onClick: () => {
            console.log('FILTER EVENT: ', field); // eslint-disable-line
            if (onFilterToggle) {
                onFilterToggle(field, !showFilters);
            }
        },
    };

    // Generate pin button props
    const pinProps = {
        iconName: pinned ? 'lock_open' : 'lock',
        iconSize: ICON_SIZE.SMALL,
        onClick: () => {
            console.log('PIN EVENT: ', field); // eslint-disable-line
            if (onPinToggle) {
                onPinToggle(field, !pinned);
            }
        },
        title: pinned ? 'unlock' : 'lock',
    };

    return (
        <div style={ {
            display: 'flex',
            justifyContent: 'center',
            alignContent: 'center',
            alignItems: 'center',
        } }>
            <TextLabel>
                { displayName }
            </TextLabel>
            <IconButton { ...pinProps } />
            { enableSorting &&
                <IconButton { ...sortProps } />
            }
            { filterableColumns &&
                <IconButton { ...filterProps } />
            }
        </div>
    );
};

DataTableColumnHeader.propTypes = {
    agGridReact: PropTypes.object,
    api: PropTypes.object,
    column: PropTypes.object,
    columnApi: PropTypes.object,
    displayName: PropTypes.string.isRequired,
    enableMenu: PropTypes.bool,
    enableSorting: PropTypes.bool,
    filterableColumns: PropTypes.bool,
    frameworkComponentWrapper: PropTypes.object,
    onFilterToggle: PropTypes.func,
    onPinToggle: PropTypes.func,
    onSortChanged: PropTypes.func,
    progressSort: PropTypes.func,
    reactContainer: PropTypes.object,
    setSort: PropTypes.func,
    showColumnMenu: PropTypes.func,
    showFilters: PropTypes.bool,
    sortDirection: PropTypes.string,
    sortDirections: PropTypes.shape({
        NONE: PropTypes.string,
        ASC: PropTypes.string,
        DESC: PropTypes.string,
    }),
};

DataTableColumnHeader.defaultProps = {};

export default DataTableColumnHeader;

==> cv-library-react-web-0.1.23.tgz: package/src/components/DataTableColumnHeader/DataTableColumnHeader.js <==
import React from 'react';
import * as PropTypes from 'prop-types';

import TextLabel from '../TextLabel/TextLabel';
import IconButton, { ICON_SIZE } from '../IconButton/IconButton';

/**
 * Data Table Column Header with sort and filter controls
 */
const DataTableColumnHeader = (props) => {
    console.log('DATA TABLE COLUMN HEADER PROPS: ', props); // eslint-disable-line

    const {
        column,
        displayName,
        enableSorting,
        filterableColumns,
        showFilters,
        onFilterToggle,
        onPinToggle,
        onSortChanged,
        sortDirection,
        sortDirections: SORT_DIRECTIONS,
    } = props;
    const {
        colDef,
        pinned,
    } = column;
    const {
        field,
    } = colDef;

    // Determine current sorting method
    const sortingAscending = sortDirection === SORT_DIRECTIONS.ASC;
    const sortingDescending = sortDirection === SORT_DIRECTIONS.DESC;
    const notSorting = !sortingAscending && !sortingDescending;

    // Determine next sorting method
    let nextSort = SORT_DIRECTIONS.ASC;
    if (sortDirection === SORT_DIRECTIONS.ASC) {
        nextSort = SORT_DIRECTIONS.DESC;
    }
    else if (sortDirection === SORT_DIRECTIONS.DESC) {
        nextSort = SORT_DIRECTIONS.NONE;
    }

    // Generate sort button props
    const sortProps = {
        contextStyles: {
            container: {},
            icon: {
                // Invert icon for sort descending as one was not in the core library
                transform: `scaleY(${sortingDescending ? -1 : 1})`,

                // Change opacity to denote cleared sort
                opacity: notSorting ? 0.25 : 1,
            },
        },
        iconName: 'sort',
        iconSize: ICON_SIZE.SMALL,
        onClick: () => {
            console.log('DATA TABLE: COLUMN HEADER: SORT EVENT: ', field); // eslint-disable-line
            if (onSortChanged) {
                onSortChanged(field, nextSort);
            }
        },
    };

    // Generate filter button props
    const filterProps = {
        iconName: 'filter_list',
        iconSize: ICON_SIZE.SMALL,
        onClick: () => {
            console.log('DATA TABLE: COLUMN HEADER: FILTER EVENT: ', field); // eslint-disable-line
            if (onFilterToggle) {
                onFilterToggle(field, !showFilters);
            }
        },
    };

    // Generate pin button props
    const pinProps = {
        iconName: pinned ? 'lock_open' : 'lock',
        iconSize: ICON_SIZE.SMALL,
        onClick: () => {
            console.log('DATA TABLE: COLUMN HEADER: PIN EVENT: ', field); // eslint-disable-line
            if (onPinToggle) {
                onPinToggle(field, !pinned);
            }
        },
        title: pinned ? 'unlock' : 'lock',
    };

    return (
        <div style={ {
            display: 'flex',
            justifyContent: 'center',
            alignContent: 'center',
            alignItems: 'center',
        } }>
            <TextLabel>
                { displayName }
            </TextLabel>
            <IconButton { ...pinProps } />
            { enableSorting &&
                <IconButton { ...sortProps } />
            }
            { filterableColumns &&
                <IconButton { ...filterProps } />
            }
        </div>
    );
};

DataTableColumnHeader.propTypes = {
    agGridReact: PropTypes.object,
    api: PropTypes.object,
    column: PropTypes.object,
    columnApi: PropTypes.object,
    displayName: PropTypes.string.isRequired,
    enableMenu: PropTypes.bool,
    enableSorting: PropTypes.bool,
    filterableColumns: PropTypes.bool,
    frameworkComponentWrapper: PropTypes.object,
    onFilterToggle: PropTypes.func,
    onPinToggle: PropTypes.func,
    onSortChanged: PropTypes.func,
    progressSort: PropTypes.func,
    reactContainer: PropTypes.object,
    setSort: PropTypes.func,
    showColumnMenu: PropTypes.func,
    showFilters: PropTypes.bool,
    sortDirection: PropTypes.string,
    sortDirections: PropTypes.shape({
        NONE: PropTypes.string,
        ASC: PropTypes.string,
        DESC: PropTypes.string,
    }),
};

DataTableColumnHeader.defaultProps = {};

export default DataTableColumnHeader;
